@@ -34,7 +34,7 @@ loop = asyncio.new_event_loop()
 twa = ThreadWrapper_async(asyncio.Semaphore(limit), loop=loop)
 for i in range(times):
     job = a2(i**2, c=i**3)
-    twa.add(job)
+    twa.add(job=job)
 twa.wait()
 e = time.time()-start
 print(times, e, e/times)
