@@ -1,5 +1,5 @@
-__version__ = "0.9.0"
-__keywords__ = ["thread wrapper class asyncio"]
+__version__ = "0.10.0"
+__keywords__ = ["thread wrapper asyncio"]
 
 
 if not __version__.endswith(".0"):
